@@ -641,7 +641,7 @@ void logistic_sim(int* tite,
                   double* inconc_rat, double* early_finding_rat,
                   double* n_treated_tab)
 {
-  try {
+  BEGIN_RCPP // Handle C++ exceptions properly
 
   TITE = *tite;
   if(TITE) {
@@ -770,11 +770,8 @@ void logistic_sim(int* tite,
 
   *inconc_rat = (double)inconc / *ntrial;
   *early_finding_rat = (double)early_finding / *ntrial;
-  }
-  catch (std::logic_error &e) { Rf_error("Internal error in dfcomb (details: %s)", e.what()); }
-  catch (...) { Rf_error("Internal error in dfcomb"); }
 
-  return;
+  VOID_END_RCPP
 }
 
 R_NativePrimitiveArgType logistic_next_args[] =
@@ -823,7 +820,7 @@ void logistic_next(int* tite,
                    double* pi, double* ptox, double* ptox_inf_targ,
                    double* ptox_targ, double* ptox_sup_targ)
 {
-  try {
+  BEGIN_RCPP // Handle C++ exceptions properly
 
   TITE = *tite;
   if(TITE) TIMEFULL = *timefull;
@@ -863,8 +860,8 @@ void logistic_next(int* tite,
     if(TITE) {
       data.time_ev.push_back(time_ev[i]);
       if(*trial_end && time_follow[i] < TIMEFULL)
-        Rf_error("dfcomb : the final recommendation cannot be computed when "
-              "all the patients have not been fully followed");
+        Rcpp::stop("dfcomb : the final recommendation cannot be computed when "
+                   "all the patients have not been fully followed");
       data.time_follow.push_back(time_follow[i]);
     } else {
       data.delta.push_back(delta[i]);
@@ -898,7 +895,6 @@ void logistic_next(int* tite,
 
   *cdose1 = data.cdose1;
   *cdose2 = data.cdose2;
-  }
-  catch (std::logic_error &e) { Rf_error("Internal error in dfcomb (details: %s)", e.what()); }
-  catch (...) { Rf_error("Internal error in dfcomb"); }
+
+  VOID_END_RCPP
 }
